==> nextcloud-19.0.6.zip: nextcloud/apps/workflowengine/l10n/fr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'opérateur donné est invalide",
    "The given regular expression is invalid" : "L'expression régulière donnée est invalide",
    "The given file size is invalid" : "La taille du fichier donné est invalide",
    "The given tag id is invalid" : "L’identifiant de l'étiquette donné est invalide",
    "The given IP range is invalid" : "La plage d'adresse IP donnée est invalide",
    "The given IP range is not valid for IPv4" : "La plage d'adresse IP donnée n'est pas valide pour l'IPv4",
    "The given IP range is not valid for IPv6" : "La plage d'adresse IP donnée n'est pas valide pour l'IPv6",
    "The given time span is invalid" : "La durée est invalide",
    "The given start time is invalid" : "La date de début est invalide",
    "The given end time is invalid" : "La date de fin est invalide",
    "The given group does not exist" : "Le groupe donné n'existe pas",
    "File" : "Fichier",
    "File created" : "Fichier créé",
    "File updated" : "Fichier mis à jour",
    "File renamed" : "Fichier renommé",
    "File deleted" : "Fichier supprimé",
    "File accessed" : "Fichier accédé",
    "File copied" : "Fichier copié",
    "Tag assigned" : "Étiquette assignée",
    "Someone" : "Quelqu'un",
    "%s created %s" : "%s créé %s",
    "%s modified %s" : "%s modifié %s",
    "%s deleted %s" : "%s supprimé %s",
    "%s accessed %s" : "%sa accédé à %s",
    "%s renamed %s" : "%s renommé %s",
    "%s copied %s" : "%s copié %s",
    "%s assigned %s to %s" : "%s a assigné %sà %s",
    "Operation #%s does not exist" : "L'opération #%s n'existe pas",
    "Entity %s does not exist" : "L'entité %sn'existe pas",
    "Entity %s is invalid" : "L'entité %s est non valide",
    "No events are chosen." : "Aucun évènement a été choisi.",
    "Entity %s has no event %s" : "L'entité %sn'a aucun évènement %s",
    "Operation %s does not exist" : "L'opération %s n'existe pas",
    "Operation %s is invalid" : "L'opération %s est invalide",
    "At least one check needs to be provided" : "Au moins une vérification doit être fournie",
    "Invalid check provided" : "Vérification non valide fournie",
    "Check %s does not exist" : "Vérifiez si %s n'existe pas",
    "Check %s is invalid" : "Vérifiez si %s est invalide",
    "Check %s is not allowed with this entity" : "La vérification %s n'est pas autorisée avec cette entité",
    "Check #%s does not exist" : "Vérifiez si #%s n'existe pas",
    "Check %s is invalid or does not exist" : "Vérifiez si %s est invalide ou n'existe pas",
    "Flow" : "Flux",
    "Nextcloud workflow engine" : "Moteur de workflow Nextcloud",
    "Select a filter" : "Sélectionner un filtre",
    "Select a comparator" : "Sélectionnez un comparateur",
    "Select a file type" : "Sélectionnez un type de fichier",
    "e.g. httpd/unix-directory" : "par exemple httpd/unix-directory",
    "Folder" : "Dossier",
    "Images" : "Images",
    "Office documents" : "Documents Office",
    "PDF documents" : "Documents PDF",
    "Custom mimetype" : "mimetype personnalisé",
    "Select a tag" : "Choisir une étiquette",
    "No results" : "Aucun résultat",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restreint)",
    "Please enter a valid time span" : "Merci de saisir une période de temps valide",
    "Select a request URL" : "Sélectionnez une requête URL",
    "Predefined URLs" : "URL prédéfinis",
    "Files WebDAV" : "Fichiers WebDAV",
    "Others" : "Autres",
    "Custom URL" : "URL personnalisée",
    "Select a user agent" : "Sélectionnez un utilisateur",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client de bureau",
    "Thunderbird & Outlook addons" : "Modules complémentaires Thunderbird & Outlook",
    "Custom user agent" : "Agent utilisateur personnalisé",
    "At least one event must be selected" : "Au moins un événement doit être sélectionné",
    "Add new flow" : "Ajouter un nouveau flux",
    "When" : "Quand",
    "and" : "et",
    "Cancel" : "Annuler",
    "Delete" : "Supprimer",
    "The configuration is invalid" : "Configuration non valide",
    "Active" : "Actif",
    "Save" : "Enregistrer",
    "Available flows" : "Flux disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Pour savoir comment rédiger votre propre flux, consultez la documentation sur le développement.",
    "More flows" : "Plus de flux",
    "Browse the app store" : "Parcourir l'App Store",
    "Show less" : "Afficher moins",
    "Show more" : "Afficher plus",
    "Configured flows" : "Flux configurés",
    "Your flows" : "Vos flux",
    "matches" : "correspond",
    "does not match" : "ne correspond pas",
    "is" : "est",
    "is not" : "n'est pas",
    "File name" : "Nom du fichier",
    "File MIME type" : "Type MIME du fichier",
    "File size (upload)" : "Taille du fichier ( à télécharger )",
    "less" : "moins",
    "less or equals" : "inférieur ou égal",
    "greater or equals" : "supérieur ou égal",
    "greater" : "plus grand que",
    "Request remote address" : "Demander une adresse distante",
    "matches IPv4" : "correspond à une adresse IPv4",
    "does not match IPv4" : "ne correspond pas à une adresse IPv4",
    "matches IPv6" : "correspond à une adresse IPv6",
    "does not match IPv6" : "ne correspond pas à une adresse IPv6",
    "File system tag" : "Étiquette collaborative du fichier",
    "is tagged with" : "est étiqueté avec",
    "is not tagged with" : "n'est pas étiqueté avec",
    "Request URL" : "Demande d'URL",
    "Request time" : "Temps de requête",
    "between" : "entre",
    "not between" : "en dehors de",
    "Request user agent" : "Agent utilisateur requis",
    "User group membership" : "Membre du groupe d'utilisateur",
    "is member of" : "est membre de",
    "is not member of" : "n'est pas membre de"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-26.0.13.zip: nextcloud/apps/workflowengine/l10n/fr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'opérateur donné est invalide",
    "The given regular expression is invalid" : "L’expression régulière donnée est invalide",
    "The given file size is invalid" : "La taille du fichier donnée est invalide",
    "The given tag id is invalid" : "L’identifiant de l'étiquette donné est invalide",
    "The given IP range is invalid" : "La plage d’adresses IP donnée est invalide",
    "The given IP range is not valid for IPv4" : "La plage d’adresses IP donnée n’est pas valide pour l’IPv4",
    "The given IP range is not valid for IPv6" : "La plage d’adresses IP donnée n’est pas valide pour l’IPv6",
    "The given time span is invalid" : "La durée est invalide",
    "The given start time is invalid" : "La date de début est invalide",
    "The given end time is invalid" : "La date de fin est invalide",
    "The given group does not exist" : "Le groupe donné n'existe pas",
    "File" : "Fichier",
    "File created" : "Fichier créé",
    "File updated" : "Fichier mis à jour",
    "File renamed" : "Fichier renommé",
    "File deleted" : "Fichier supprimé",
    "File accessed" : "Fichier accédé",
    "File copied" : "Fichier copié",
    "Tag assigned" : "Étiquette assignée",
    "Someone" : "Quelqu'un",
    "%s created %s" : "%s créé %s",
    "%s modified %s" : "%s modifié %s",
    "%s deleted %s" : "%s supprimé %s",
    "%s accessed %s" : "%sa accédé à %s",
    "%s renamed %s" : "%s renommé %s",
    "%s copied %s" : "%s copié %s",
    "%s assigned %s to %s" : "%s a assigné %sà %s",
    "Operation #%s does not exist" : "L'opération #%s n'existe pas",
    "Entity %s does not exist" : "L'entité %sn'existe pas",
    "Entity %s is invalid" : "L'entité %s est non valide",
    "No events are chosen." : "Aucun évènement a été choisi.",
    "Entity %s has no event %s" : "L'entité %sn'a aucun évènement %s",
    "Operation %s does not exist" : "L'opération %s n'existe pas",
    "Operation %s is invalid" : "L’opération %s est invalide",
    "At least one check needs to be provided" : "Au moins une condition doit être fournie",
    "The provided operation data is too long" : "Les données d’opération fournies sont trop longues",
    "Invalid check provided" : "Condition proposée invalide",
    "Check %s does not exist" : "La condition %s n'existe pas",
    "Check %s is invalid" : "La condition %s est invalide",
    "Check %s is not allowed with this entity" : "La condition %s n'est pas autorisée avec cette entité",
    "The provided check value is too long" : "La valeur de la condition fournie est trop longue",
    "Check #%s does not exist" : "La condition #%s n'existe pas",
    "Check %s is invalid or does not exist" : "La condition %s est invalide ou n'existe pas",
    "Flow" : "Flux",
    "Nextcloud workflow engine" : "Moteur de workflow Nextcloud",
    "Select a filter" : "Sélectionner un filtre",
    "Select a comparator" : "Sélectionnez un comparateur",
    "Remove filter" : "Retirer le filtre",
    "Select a file type" : "Sélectionnez un type de fichier",
    "e.g. httpd/unix-directory" : "par exemple httpd/unix-directory",
    "Folder" : "Dossier",
    "Images" : "Images",
    "Office documents" : "Documents Office",
    "PDF documents" : "Documents PDF",
    "Custom MIME type" : "Type MIME personnalisé",
    "Custom mimetype" : "mimetype personnalisé",
    "Please enter a valid time span" : "Merci de saisir une période de temps valide",
    "Select a request URL" : "Sélectionnez une requête URL",
    "Files WebDAV" : "Fichiers WebDAV",
    "Custom URL" : "URL personnalisée",
    "Select a user agent" : "Sélectionner un client",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client de bureau",
    "Thunderbird & Outlook addons" : "Modules complémentaires Thunderbird & Outlook",
    "Custom user agent" : "Autre client",
    "Select groups" : "Sélectionnez les groupes",
    "Groups" : "Groupes",
    "Select a trigger" : "Sélectionner un déclencheur",
    "At least one event must be selected" : "Au moins un événement doit être sélectionné",
    "Add new flow" : "Ajouter un nouveau flux",
    "When" : "Quand",
    "and" : "et",
    "Add a new filter" : "Ajouter une condition",
    "Cancel" : "Annuler",
    "Delete" : "Supprimer",
    "The configuration is invalid" : "Configuration non valide",
    "Active" : "Actif",
    "Save" : "Enregistrer",
    "Available flows" : "Flux disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Pour savoir comment rédiger votre propre flux, consultez la documentation sur le développement.",
    "No flows installed" : "Aucun flux n'est installé",
    "Ask your administrator to install new flows." : "Demandez à votre administrateur d'installer de nouveaux flux.",
    "More flows" : "Plus de flux",
    "Browse the App Store" : "Parcourir le magasin d'applications",
    "Show less" : "Afficher moins",
    "Show more" : "Afficher plus",
    "Configured flows" : "Flux configurés",
    "Your flows" : "Vos flux",
    "No flows configured" : "Aucun flux n'est configuré",
    "matches" : "correspond",
    "does not match" : "ne correspond pas",
    "is" : "est",
    "is not" : "n’est pas",
    "File name" : "Nom du fichier",
    "File MIME type" : "Type MIME du fichier",
    "File size (upload)" : "Taille du fichier (à téléverser)",
    "less" : "moins",
    "less or equals" : "inférieur ou égal",
    "greater or equals" : "supérieur ou égal",
    "greater" : "plus grand que",
    "Request remote address" : "Adresse IP de la requête",
    "matches IPv4" : "correspond à une adresse IPv4",
    "does not match IPv4" : "ne correspond pas à une adresse IPv4",
    "matches IPv6" : "correspond à une adresse IPv6",
    "does not match IPv6" : "ne correspond pas à une adresse IPv6",
    "File system tag" : "Étiquette collaborative du fichier",
    "is tagged with" : "est étiqueté avec",
    "is not tagged with" : "n'est pas étiqueté avec",
    "Request URL" : "Demande d'URL",
    "Request time" : "Horaire de l'événement",
    "between" : "entre",
    "not between" : "en dehors de",
    "Request user agent" : "Client utilisé pour la requête",
    "is member of" : "est membre de",
    "is not member of" : "n’est pas membre de",
    "User group membership" : "Membre du groupe d'utilisateur"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
